==> 0.1.90.tar.gz: lib/statusText.dart <==
import 'package:feed_plugin/utilities/colors.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/screen_util.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class StatusText extends StatefulWidget {
  _StatusTextState createState() => _StatusTextState();
}

class _StatusTextState extends State<StatusText> {
  final statusText = TextEditingController();
  Color statusColor = Colors.yellow;
  String statusColorString = "Yellow";
  @override
  Widget build(BuildContext context) {
    checkIsHebrew(String text) {
      var enLen;
      var heLen;
      if (text != "" && text.contains(RegExp(r'[א-ת]'))) {
        heLen = 1;
      } else if (text != "") {
        enLen = 1;
      }
      if (heLen == 1) return true;

      return false;
    }

    var width = MediaQuery.of(context).size.width;
    var height = MediaQuery.of(context).size.height;
    return Directionality(
        textDirection: TextDirection.ltr,
        child: ScreenUtilInit(
            designSize: Size(width, height),
            allowFontScaling: false,
            builder: () => (Scaffold(
                backgroundColor: Colors.grey[200],
                appBar: PreferredSize(
                  preferredSize: Size.fromHeight(70.0),
                  child: AppBar(
                    backgroundColor: primaryColor,
                    title: Center(
                        child: Padding(
                      padding: EdgeInsets.only(top: ScreenUtil().setHeight(8)),
                      child: Text("Status Text"),
                    )),
                    actions: [
                      GestureDetector(
                        onTap: () => Navigator.pop(
                            context, [statusText.text, statusColorString]),
                        child: Padding(
                          padding: EdgeInsets.only(
                              top: ScreenUtil().setHeight(8),
                              right: ScreenUtil().setWidth(8)),
                          child: Icon(Icons.check),
                        ),
                      ),
                    ],
                  ),
                ),
                body: Padding(
                  padding: EdgeInsets.only(top: ScreenUtil().setHeight(80)),
                  child: ListView(children: [
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: <Widget>[
                        Container(
                            width: ScreenUtil().setWidth(300),
                            height: ScreenUtil().setHeight(300),
                            color: statusColor,
                            child: TextFormField(
                              onChanged: (text) {
                                if (checkIsHebrew(statusText.text)) {
                                  setState(() {
                                    checkIsHebrew("עברית");
                                  });
                                } else {
                                  setState(() {
                                    checkIsHebrew("English");
                                  });
                                }
                              },
                              textDirection: checkIsHebrew(statusText.text)
                                  ? TextDirection.rtl
                                  : TextDirection.ltr,
                              maxLines: null,
                              style: TextStyle(
                                  color: Colors.white,
                                  fontSize: ScreenUtil().setHeight(30)),
                              textAlign: TextAlign.center,
                              decoration: InputDecoration(
                                  border: InputBorder.none,
                                  hintText: 'Type status:',
                                  counterText: ""),
                              maxLength: 200,
                              controller: statusText,
                            )),
                        Padding(
                          padding:
                              EdgeInsets.only(top: ScreenUtil().setHeight(10)),
                          child: Row(
                            mainAxisAlignment: MainAxisAlignment.center,
                            children: <Widget>[
                              Padding(
                                padding: EdgeInsets.only(
                                    right: ScreenUtil().setWidth(8)),
                                // ignore: deprecated_member_use
                                child: RaisedButton(
                                  color: Colors.yellow,
                                  child: Text("Yellow"),
                                  onPressed: () {
                                    setState(() {
                                      statusColorString = "Yellow";
                                      statusColor = Colors.yellow;
                                      statusColorString = "yellow";
                                    });
                                  },
                                ),
                              ),
                              Padding(
                                padding: EdgeInsets.only(
                                    right: ScreenUtil().setWidth(8)),
                                // ignore: deprecated_member_use
                                child: RaisedButton(
                                  color: Colors.green,
                                  child: Text("Green"),
                                  onPressed: () {
                                    setState(() {
                                      statusColorString = "Green";
                                      statusColor = Colors.green;
                                    });
                                  },
                                ),
                              ),
                              // ignore: deprecated_member_use
                              RaisedButton(
                                color: Colors.blue,
                                child: Text("Blue"),
                                onPressed: () {
                                  setState(() {
                                    statusColorString = "Blue";
                                    statusColor = Colors.blue;
                                  });
                                },
                              ),
                            ],
                          ),
                        ),
                        Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: <Widget>[
                            Padding(
                              padding: EdgeInsets.only(
                                  right: ScreenUtil().setWidth(8)),
                              // ignore: deprecated_member_use
                              child: RaisedButton(
                                color: Colors.red,
                                child: Text("Red"),
                                onPressed: () {
                                  setState(() {
                                    statusColorString = "Red";
                                    statusColor = Colors.red;
                                  });
                                },
                              ),
                            ),
                            Padding(
                              padding: EdgeInsets.only(
                                  right: ScreenUtil().setWidth(8)),
                              // ignore: deprecated_member_use
                              child: RaisedButton(
                                color: Colors.orange,
                                child: Text("Orange"),
                                onPressed: () {
                                  setState(() {
                                    statusColorString = "Orange";
                                    statusColor = Colors.orange;
                                  });
                                },
                              ),
                            ),
                            // ignore: deprecated_member_use
                            RaisedButton(
                              color: Colors.pink,
                              child: Text("Pink"),
                              onPressed: () {
                                setState(() {
                                  statusColorString = "Pink";
                                  statusColor = Colors.pink;
                                });
                              },
                            ),
                          ],
                        ),
                        Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: <Widget>[
                            Padding(
                              padding: EdgeInsets.only(
                                  right: ScreenUtil().setWidth(8)),
                              // ignore: deprecated_member_use
                              child: RaisedButton(
                                color: Colors.black54,
                                child: Text("Black"),
                                onPressed: () {
                                  setState(() {
                                    statusColorString = "Black";
                                    statusColor = Colors.black54;
                                  });
                                },
                              ),
                            ),
                            Padding(
                              padding: EdgeInsets.only(
                                  right: ScreenUtil().setWidth(8)),
                              // ignore: deprecated_member_use
                              child: RaisedButton(
                                color: Colors.purple,
                                child: Text("Purple"),
                                onPressed: () {
                                  setState(() {
                                    statusColorString = "Purple";
                                    statusColor = Colors.purple;
                                  });
                                },
                              ),
                            ),
                            // ignore: deprecated_member_use
                            RaisedButton(
                              color: Colors.grey,
                              child: Text("Grey"),
                              onPressed: () {
                                setState(() {
                                  statusColorString = "Grey";
                                  statusColor = Colors.grey;
                                });
                              },
                            ),
                          ],
                        )
                      ],
                    ),
                  ]),
                )))));
  }
}

==> 0.2.11.tar.gz: lib/statusText.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_screenutil/screen_util.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class StatusText extends StatefulWidget {
  _StatusTextState createState() => _StatusTextState();
}

class _StatusTextState extends State<StatusText> {
  final statusText = TextEditingController();
  Color statusColor = Colors.yellow;
  String statusColorString = "Yellow";
  @override
  Widget build(BuildContext context) {
    var width = MediaQuery.of(context).size.width;
    var height = MediaQuery.of(context).size.height;
    // final Size size = MediaQuery.of(context).size;
    // final double categoryHeight = size.height * 0.30;
    return Directionality(
        textDirection: TextDirection.ltr,
        child: ScreenUtilInit(
            designSize: Size(width, height),
            allowFontScaling: false,
            builder: () => (Scaffold(
                backgroundColor: Colors.grey[200],
                appBar: PreferredSize(
                  preferredSize: Size.fromHeight(70.0),
                  child: AppBar(
                    backgroundColor: Color(0xFF083356),
                    title: Center(
                        child: Padding(
                      padding: EdgeInsets.only(top: ScreenUtil().setHeight(8)),
                      child: Text("Status Text"),
                    )),
                    actions: [
                      GestureDetector(
                        onTap: () => Navigator.pop(
                            context, [statusText.text, statusColorString]),
                        child: Padding(
                          padding: EdgeInsets.only(
                              top: ScreenUtil().setHeight(8),
                              right: ScreenUtil().setWidth(8)),
                          child: Icon(Icons.check),
                        ),
                      ),
                    ],
                  ),
                ),
                body: Padding(
                  padding: EdgeInsets.only(top: ScreenUtil().setHeight(80)),
                  child: ListView(children: [
                    Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: <Widget>[
                        Container(
                            width: ScreenUtil().setWidth(300),
                            height: ScreenUtil().setHeight(300),
                            color: statusColor,
                            child: TextField(
                              maxLines: null,
                              style: TextStyle(
                                  color: Colors.white,
                                  fontSize: ScreenUtil().setHeight(30)),
                              textAlign: TextAlign.center,
                              decoration: InputDecoration(
                                  border: InputBorder.none,
                                  hintText: 'Type status:',
                                  counterText: ""),
                              maxLength: 200,
                              controller: statusText,
                            )),
                        Padding(
                          padding:
                              EdgeInsets.only(top: ScreenUtil().setHeight(10)),
                          child: Row(
                            mainAxisAlignment: MainAxisAlignment.center,
                            children: <Widget>[
                              Padding(
                                padding: EdgeInsets.only(
                                    right: ScreenUtil().setWidth(8)),
                                child: RaisedButton(
                                  color: Colors.yellow,
                                  child: Text("Yellow"),
                                  onPressed: () {
                                    setState(() {
                                      statusColorString = "Yellow";
                                      statusColor = Colors.yellow;
                                      statusColorString = "yellow";
                                    });
                                  },
                                ),
                              ),
                              Padding(
                                padding: EdgeInsets.only(
                                    right: ScreenUtil().setWidth(8)),
                                child: RaisedButton(
                                  color: Colors.green,
                                  child: Text("Green"),
                                  onPressed: () {
                                    setState(() {
                                      statusColorString = "Green";
                                      statusColor = Colors.green;
                                    });
                                  },
                                ),
                              ),
                              RaisedButton(
                                color: Colors.blue,
                                child: Text("Blue"),
                                onPressed: () {
                                  setState(() {
                                    statusColorString = "Blue";
                                    statusColor = Colors.blue;
                                  });
                                },
                              ),
                            ],
                          ),
                        ),
                        Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: <Widget>[
                            Padding(
                              padding: EdgeInsets.only(
                                  right: ScreenUtil().setWidth(8)),
                              child: RaisedButton(
                                color: Colors.red,
                                child: Text("Red"),
                                onPressed: () {
                                  setState(() {
                                    statusColorString = "Red";
                                    statusColor = Colors.red;
                                  });
                                },
                              ),
                            ),
                            Padding(
                              padding: EdgeInsets.only(
                                  right: ScreenUtil().setWidth(8)),
                              child: RaisedButton(
                                color: Colors.orange,
                                child: Text("Orange"),
                                onPressed: () {
                                  setState(() {
                                    statusColorString = "Orange";
                                    statusColor = Colors.orange;
                                  });
                                },
                              ),
                            ),
                            RaisedButton(
                              color: Colors.pink,
                              child: Text("Pink"),
                              onPressed: () {
                                setState(() {
                                  statusColorString = "Pink";
                                  statusColor = Colors.pink;
                                });
                              },
                            ),
                          ],
                        ),
                        Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: <Widget>[
                            Padding(
                              padding: EdgeInsets.only(
                                  right: ScreenUtil().setWidth(8)),
                              child: RaisedButton(
                                color: Colors.black54,
                                child: Text("Black"),
                                onPressed: () {
                                  setState(() {
                                    statusColorString = "Black";
                                    statusColor = Colors.black54;
                                  });
                                },
                              ),
                            ),
                            Padding(
                              padding: EdgeInsets.only(
                                  right: ScreenUtil().setWidth(8)),
                              child: RaisedButton(
                                color: Colors.purple,
                                child: Text("Purple"),
                                onPressed: () {
                                  setState(() {
                                    statusColorString = "Purple";
                                    statusColor = Colors.purple;
                                  });
                                },
                              ),
                            ),
                            RaisedButton(
                              color: Colors.grey,
                              child: Text("Grey"),
                              onPressed: () {
                                setState(() {
                                  statusColorString = "Grey";
                                  statusColor = Colors.grey;
                                });
                              },
                            ),
                          ],
                        )
                      ],
                    ),
                  ]),
                )))));
  }
}
